Module: ExternalFields
- Extended by:
- ActiveSupport::Concern
- Defined in:
- lib/external_fields.rb,
lib/external_fields/version.rb
Overview
This concern maintains the illusion that a given object has specified attributes, when those attributes are in fact attached to an associated object. This is particularly useful for different classes within a single- table inheritance table to have access to separate fields in class-specific associations.
Constant Summary collapse
- VERSION =
"0.1.3"